# Changelog

## v0.1.0 (released 2025-05-12)

### Features and Improvements

- Add support for extracting columns and types from a model. [[f4178ae](https://github.com/NRWLDev/pydantic-db/commit/f4178ae54efffffe65da50718fffb389a21a4977)]
- Add support for nested models [[998ab19](https://github.com/NRWLDev/pydantic-db/commit/998ab191d07afaba9ad12b69671b875227a63620)]
- Basic database model mapping for result and list of results. [[f007a01](https://github.com/NRWLDev/pydantic-db/commit/f007a012c97b7b4c00eebcb1503035408e74c267)]

### Miscellaneous

- Expand tests to confirm support for sqlite [[b40c806](https://github.com/NRWLDev/pydantic-db/commit/b40c806fdb2531deece4e195f0f5eb77fea29596)]
- Expand test coverage [[b69fbe0](https://github.com/NRWLDev/pydantic-db/commit/b69fbe09a9f1f0097b53c3fa6acd77e946602d8c)]
